netapp_ontap.models.node_controller_frus API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_controller_frus`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeControllerFrusSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeControllerFrus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `id GET`

    The id field of the node_controller_frus.

  `state GET`

    The state field of the node_controller_frus.

    Valid choices:

    - ok
    - error
  `type GET`

    The type field of the node_controller_frus.

    Valid choices:

    - fan
    - psu
    - pcie
    - disk
    - nvs
    - dimm
    - controller